@@ -1,8 +1,10 @@
 from .fdbscan import FDBSCAN
 from .velocity_fragmentator import VelocityFragmentator
+from .stcm import STCM
 
 
 __all__ = [
     "FDBSCAN",
     "VelocityFragmentator",
+    "STCM",
 ]
